@@ -9,7 +9,7 @@ use Pod::Abstract::BuildNode qw(node nodes);
 
 
 use vars qw($VERSION);
-$VERSION = '1.06';
+$VERSION = '1.07';
 
 # This Module is designed to generate pod documentation of a perl class by analysing its code.
 # The idea is to have something similar like javadoc. So it uses also comments written directly
@@ -24,6 +24,8 @@ $VERSION = '1.06';
 # SYNOPSIS
 # ========
 #
+#  use Pod::Autopod;
+#
 #  new Pod::Autopod(readfile=>'Foo.pm', writefile=>'Foo2.pm');
 # 
 #  # reading Foo.pm and writing Foo2.pm but with pod
@@ -34,8 +36,6 @@ $VERSION = '1.06';
 #
 #  # reading and Foo.pm and prints the generated pod. 
 #
-#  use Pod::Autopod;
-#
 #  my $ap = new Pod::Autopod();
 #  $ap->setPerlCode($mycode);
 #  print $ap->getPod();
@@ -206,27 +206,51 @@ my %v=@_;
 	
 
 	if ($this->{'readfile'}){
-		my $arr = $this->_getFileArray($this->{'readfile'});
-		$this->setPerlCode($arr);
+		$this->readFile($this->{'readfile'});
 	}
 
 
-	my $border = '#' x 20;
-	$border .= " pod generated by $pkg - keep this line to make pod updates possible ";
-	$border .= '#' x 20;
-	$this->{'BORDER'}=$border;
-		
-
-
 	if ($this->{'writefile'}){
 		$this->writeFile($this->{'writefile'});
 	}
-	
+
+
+	if ($this->{'readdir'}){
+		$this->readDirectory($this->{'readdir'});
+	}	
 
 return $this;
 }  
 
 
+## Returns the border string which delimit the perl code and pod inside a pm file.
+sub getBorderString{ ## $scalar
+my $this=shift;
+my $pkg=$this->{'package'};
+
+	if ($this->{'BORDER'} eq ''){
+		
+		my $border = '#' x 20;
+		$border .= " pod generated by $pkg - keep this line to make pod updates possible ";
+		$border .= '#' x 20;
+		$this->{'BORDER'}=$border;
+		
+	}
+
+return $this->{'BORDER'};	
+}
+
+
+## Set an alternative border string. 
+## If you change this, you have to do it again when updating the pod.
+sub setBorderString{ ## void ($borderstring)
+my $this=shift;
+my $s=shift;
+
+	$this->{'BORDER'} =$s;
+
+}
+
 
 
 # Expects Perl code as arrayref
@@ -257,7 +281,7 @@ my $code=shift;
 sub getPerlCode{# $text
 my $this=shift;
 	
-	my $border = $this->{'BORDER'};
+	my $border = $this->getBorderString();
 	
 	my $arr = $this->{'PERL_CODE'};
 	
@@ -302,6 +326,17 @@ return wantarray ? @f : \@f;
 }
 
 
+sub _getFileScalar{
+my $this=shift;
+my $filename=shift;
+	
+	my $a = $this->_getFileArray($filename);
+
+return join("",@$a);	
+}
+
+
+
 # writes a pod file
 #
 # If the file has a pm extension, it writes the perl code and the pod
@@ -322,6 +357,180 @@ my $pod=$this->getPod();
 }
 
 
+## Reading a Perl class file and loads it to memory.
+sub readFile{ # void ($filename)
+my $this=shift;
+my $file=shift or die "need filename";
+
+
+	my $arr = $this->_getFileArray($file);
+	$this->setPerlCode($arr);
+	
+	
+}
+
+
+## scans a directoy recoursively for pm files and may
+## generate pod of them.
+##
+## You can also set the flag updateonly to build new pod
+## only for files you already build a pod (inside the file)
+## in the past. Alternatively you can write the magic word
+## AUTOPODME somewhere in the pm file what signals that this
+## pm file wants to be pod'ed by autopod.
+##
+## The flag pod let will build a separate file. If poddir set,
+## the generated pod file will be saved to a deparate directory.
+## With verbose it prints the list of written files.
+##
+sub readDirectory{ # void ($directory,updateonly=>scalar,pod=>scalar,verbose=>scalar)
+my $this=shift;
+my $directory=shift or die "need directory";
+my $v={@_};
+my $updateonly=$v->{'updateonly'};
+my $verbose=$v->{'verbose'};
+my $pod=$v->{'pod'};
+my $border=$this->getBorderString();
+
+
+	my @dir = $this->_getPodFilesRecoursive($directory);
+
+
+	foreach my $filein (@dir){
+		
+		my $fileout = $filein;
+		
+		my $filecontent = $this->_getFileScalar($filein);
+		if ($updateonly){
+			if (($filecontent!~ m/$border/) &&  ($filecontent!~ m/AUTOPODME/) ){$fileout=undef}; ## no border, no update
+		}
+		
+		if ($pod){
+			$fileout=~ s/\.pm$/.pod/;
+		}
+		
+		my $ap = new Pod::Autopod();
+		$ap->readFile($filein);
+		$ap->writeFile($fileout);
+	
+		print $fileout."\n" if $verbose && $fileout;
+		
+	}
+
+}
+
+
+
+
+
+sub _getPodFilesRecoursive{
+my $this=shift;
+my $path=shift;
+my %para=@_;
+my @files;
+
+	@files=$this->_getFilesRecoursiveAll($path);
+	$this->_filterFileArray(\@files,ext=>'pm',path=>$path);
+	@files=sort @files;
+
+return wantarray ? @files : \@files;
+}
+
+
+sub _getFilesRecoursiveAll{
+my $this=shift;
+my $path=shift;
+my %para;
+my @f;
+my @fm;
+
+
+	@f=$this->_getDirArray($path);
+
+	$this->_filterFileArray(\@f);
+	$this->_addPathToArray($path,\@f);
+
+	foreach my $d (@f){
+		if (-d $d){
+		push @fm,$this->_getFilesRecoursiveAll($d);
+		}
+	}
+	push @f,@fm;
+
+	
+	
+return @f;
+}  
+
+
+
+sub _getDirArray{
+my $this=shift;
+my $path=shift;
+my @f;
+my @nf;
+
+	opendir(FDIR,$path);
+		@f=readdir FDIR;
+	closedir(FDIR);
+
+	foreach my $d (@f){
+		if ($d!~ m/^\.\.?/){push @nf,$d};
+	}
+
+return wantarray ? @nf : \@nf;
+}
+
+
+
+sub _addPathToArray{
+my $this=shift;
+my $path=shift;
+my $dir_ref=shift;
+
+		foreach my $z (@$dir_ref){
+			$z=$path.'/'.$z;
+		}
+}
+  
+
+
+
+sub _filterFileArray{
+my $this=shift;
+my $dir_ref=shift;
+my %para=@_;
+my @nf;
+my $path=$para{path};
+
+
+	if ($para{onlyFiles} ne ''){$para{noDir}=1};
+	
+	
+	foreach my $i (@$dir_ref){
+		my $ok=1;
+		if ($i=~ m/^\.\.?$/){$ok=0};
+				
+		if (-d $i){$ok=0};
+
+		my $ext=lc($para{ext});
+		if (exists $para{ext}){
+			if ($i=~ m/\.$ext$/i){$ok=1}else{$ok=0};
+		};
+
+		if ($ok == 1){push @nf,$i};
+	}
+	@$dir_ref=@nf;
+	undef @nf;
+
+}
+  
+  
+  
+
+
+
+	
 
 sub _putFile{
 my $this=shift;
@@ -1155,11 +1364,14 @@ my $mat=$attr->{$method};
 
 	### head text 
 
-	my $text = join("",@{ $mat->{'head'} });
+	my $text;
+	if ($mat->{'head'}){
+		$text = join("",@{ $mat->{'head'} });
+		if ($text){$text.="\n\n\n"};
+	
+		$node->push( node->text($text) );
+	}
 	
-	if ($text){$text.="\n\n\n"};
-
-	$node->push( node->text($text) );
 
 
 }
@@ -1241,6 +1453,7 @@ return $c;
 
 
 
+
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
@@ -1251,6 +1464,8 @@ Pod::Autopod - Generates pod documentation by analysing perl modules.
 =head1 SYNOPSIS
 
 
+ use Pod::Autopod;
+
  new Pod::Autopod(readfile=>'Foo.pm', writefile=>'Foo2.pm');
 
  # reading Foo.pm and writing Foo2.pm but with pod
@@ -1261,7 +1476,6 @@ Pod::Autopod - Generates pod documentation by analysing perl modules.
 
  # reading and Foo.pm and prints the generated pod. 
 
-
  my $ap = new Pod::Autopod();
  $ap->setPerlCode($mycode);
  print $ap->getPod();
@@ -1328,8 +1542,9 @@ The example above produces the following method description:
 
  $this->foo($text);
 
-The object "$this" is the default and automatially used when a constructor was found ("new"). You
-can change this by the parameter "selfstring" in the autoperl constructor.
+The object "$this" is the default and automatially used when a constructor was found ("new")
+or the class inherits with ISA or "use base".
+You can change this by the parameter "selfstring" in the autopod constructor.
 
 The example looks simple, but the engine does more than you think. Please have a look here:
 
@@ -1446,6 +1661,13 @@ Builds the pod. Called automatically when imporing a perl code.
 This method is doing foo. print $this->foo();It is not doing bar, only foo.
 
 
+=head2 getBorderString
+
+ my $scalar = $this->getBorderString();
+
+Returns the border string which delimit the perl code and pod inside a pm file.
+
+
 =head2 getPerlCode
 
  my $text = $this->getPerlCode();
@@ -1460,6 +1682,20 @@ Returns perl code which was set before.
 Returns the pod formated text.s
 
 
+=head2 readDirectory
+
+ $this->readDirectory($directory, updateonly => $scalar, pod => $scalar, verbose => $scalar);
+
+scans a directoy recoursively for pm files and maygenerate pod of them.You can also set the flag updateonly to build new podonly for files you already build a pod (inside the file)in the past. Alternatively you can write the magic wordAUTOPODME somewhere in the pm file what signals that thispm file wants to be pod'ed by autopod.The flag pod let will build a separate file. If poddir set,the generated pod file will be saved to a deparate directory.With verbose it prints the list of written files.
+
+
+=head2 readFile
+
+ $this->readFile($filename);
+
+Reading a Perl class file and loads it to memory.
+
+
 =head2 scanArray
 
  $this->scanArray();
@@ -1467,6 +1703,13 @@ Returns the pod formated text.s
 This class may scan the perl code.But it is called automatically when importing a perl code.
 
 
+=head2 setBorderString
+
+ $this->setBorderString($borderstring);
+
+Set an alternative border string.If you change this, you have to do it again when updating the pod.
+
+
 =head2 setPerlCode
 
  $this->setPerlCode($text | \@array);
